![PyPI - Status](https://img.shields.io/pypi/v/pytqshacl)

# Py(thon)T(op)Q(uadrant)SHA(pe)C(onstraint)L(anguage)

Python wrapper around TopQuadrant's SHACL implementation in Java.

## Why?

Motivation: This was developed as part of [BIM2RDF](https://github.com/PNNL/BIM2RDF)
where [TopQuadrant](https://github.com/TopQuadrant/shacl) was used to execute SHACL.
Python's [PySHACL](https://github.com/RDFLib/pySHACL) was too slow.
Nonetheless, it's useful to be able to integrate it with Python.

